==> android-4.0.1.2-sources.jar: android/view/ViewPropertyAnimator.java <==
package android.view;
public class ViewPropertyAnimator
{
ViewPropertyAnimator() { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator setDuration(long duration) { throw new RuntimeException("Stub!"); }
public  long getDuration() { throw new RuntimeException("Stub!"); }
public  long getStartDelay() { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator setStartDelay(long startDelay) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator setInterpolator(android.animation.TimeInterpolator interpolator) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator setListener(android.animation.Animator.AnimatorListener listener) { throw new RuntimeException("Stub!"); }
public  void start() { throw new RuntimeException("Stub!"); }
public  void cancel() { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator x(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator xBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator y(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator yBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator rotation(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator rotationBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator rotationX(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator rotationXBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator rotationY(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator rotationYBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator translationX(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator translationXBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator translationY(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator translationYBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator scaleX(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator scaleXBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator scaleY(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator scaleYBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator alpha(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator alphaBy(float value) { throw new RuntimeException("Stub!"); }
}

==> android-4.1.1.4-sources.jar: android/view/ViewPropertyAnimator.java <==
package android.view;
public class ViewPropertyAnimator
{
ViewPropertyAnimator() { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator setDuration(long duration) { throw new RuntimeException("Stub!"); }
public  long getDuration() { throw new RuntimeException("Stub!"); }
public  long getStartDelay() { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator setStartDelay(long startDelay) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator setInterpolator(android.animation.TimeInterpolator interpolator) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator setListener(android.animation.Animator.AnimatorListener listener) { throw new RuntimeException("Stub!"); }
public  void start() { throw new RuntimeException("Stub!"); }
public  void cancel() { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator x(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator xBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator y(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator yBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator rotation(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator rotationBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator rotationX(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator rotationXBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator rotationY(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator rotationYBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator translationX(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator translationXBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator translationY(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator translationYBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator scaleX(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator scaleXBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator scaleY(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator scaleYBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator alpha(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator alphaBy(float value) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator withLayer() { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator withStartAction(java.lang.Runnable runnable) { throw new RuntimeException("Stub!"); }
public  android.view.ViewPropertyAnimator withEndAction(java.lang.Runnable runnable) { throw new RuntimeException("Stub!"); }
}
